@@ -26,7 +26,7 @@ function(file, ignoreBlanks = TRUE, handlers = NULL,
             encoding = character(),
             useDotNames = length(grep("^\\.", names(handlers))) > 0,
             xinclude = FALSE, addFinalizer = TRUE, error = function(...){},
-            options = integer())
+            options = integer(), parentFirst = FALSE)
 {
 if(TRUE) 
   {
@@ -65,8 +65,7 @@ if(TRUE)
  if(!asText && !isURL)
    file = path.expand(file)
 
- old = setEntitySubstitution(replaceEntities)
- on.exit(setEntitySubstitution(old))
+ if (replaceEntities) options <- union(options, NOENT)
 
  if(!is.logical(xinclude)) {
    if(inherits(xinclude, "numeric"))
@@ -84,7 +83,7 @@ if(TRUE)
            FALSE, FALSE, 
            as.logical(isURL), FALSE, 
            as.logical(useInternalNodes), TRUE, FALSE, FALSE, as.character(encoding),
-           as.logical(useDotNames), xinclude, error, addFinalizer, options, PACKAGE = "XML")
+           as.logical(useDotNames), xinclude, error, addFinalizer, options, as.logical(parentFirst), PACKAGE = "XML")
 
  if(!missing(handlers) & !as.logical(asTree))
    return(handlers)
@@ -153,6 +152,12 @@ setOldClass("URL")
 
 setAs("URI", "character",
       function(from) {
+          if(from$scheme == "")
+              sprintf("%s%s%s",
+                      from["path"],
+                      if(from[["query"]] != "") sprintf("?%s", from[["query"]]) else "",
+                      if(from[["fragment"]] != "") sprintf("#%s", from[["fragment"]]) else "" )
+          else
            sprintf("%s://%s%s%s%s%s%s%s",
                                     from[["scheme"]],
                                     from[["user"]],
@@ -167,15 +172,3 @@ setAs("URI", "character",
 
 
 
-getHTMLLinks =
-function(doc, externalOnly = TRUE, xpQuery = "//a/@href")
-{
-  if(is.character(doc))
-     doc = htmlParse(doc)
-
-  links = as.character(getNodeSet(doc, xpQuery))
-  if(externalOnly)
-      grep("^#", links, value = TRUE, invert = TRUE)
-  else
-     links
-}
